# unicore.ask
Universal Core REST service for Questions and Surveys.

.. image:: https://travis-ci.org/universalcore/unicore.ask.svg?branch=develop
    :target: https://travis-ci.org/universalcore/unicore.ask
    :alt: Continuous Integration

.. image:: https://coveralls.io/repos/universalcore/unicore.ask/badge.png?branch=develop
    :target: https://coveralls.io/r/universalcore/unicore.ask?branch=develop
    :alt: Code Coverage

.. image:: https://pypip.in/version/unicore.ask/badge.svg
    :target: https://pypi.python.org/pypi/unicore.ask
    :alt: Pypi Package
